fn commit_cache(db: &mut dyn Db, cache: Cache) -> Result<(), BlockchainError>Expand description
Commits a fully executed candidate cache to the live database.
fn commit_cache(db: &mut dyn Db, cache: Cache) -> Result<(), BlockchainError>Commits a fully executed candidate cache to the live database.