fn unpack_execution_result<H: IntoInstructionResult>(
result: ExecutionResult<H>,
) -> (InstructionResult, u64, Option<Output>, Vec<Log>)Expand description
Unpacks an [ExecutionResult] into its exit reason, gas used, output, and logs.
fn unpack_execution_result<H: IntoInstructionResult>(
result: ExecutionResult<H>,
) -> (InstructionResult, u64, Option<Output>, Vec<Log>)Unpacks an [ExecutionResult] into its exit reason, gas used, output, and logs.