MonadReplayContext

Type Alias MonadReplayContext 

pub(crate) type MonadReplayContext = MonadChainContext;
Available on crate feature monad only.

Aliased Type

pub(crate) struct MonadReplayContext {
    pub parent_senders_and_authorities: HashSet<Address, DefaultHashBuilder>,
    pub grandparent_senders_and_authorities: HashSet<Address, DefaultHashBuilder>,
    pub current_block_senders: Vec<Address>,
    pub current_block_authorities: Vec<Vec<Address>>,
    pub current_tx_index: usize,
    pub max_reserve_balance: Uint<256, 4>,
}

Fields

parent_senders_and_authorities: HashSet<Address, DefaultHashBuilder>

Combined senders and authorities from the parent block.

grandparent_senders_and_authorities: HashSet<Address, DefaultHashBuilder>

Combined senders and authorities from the grandparent block.

current_block_senders: Vec<Address>

Senders already present in the current block.

current_block_authorities: Vec<Vec<Address>>

Authorities already present in the current block.

current_tx_index: usize

Index of the current transaction within the current block metadata.

max_reserve_balance: Uint<256, 4>

Maximum reserve balance to enforce for accounts.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 168 bytes