OpCallDepositInfo

Type Alias OpCallDepositInfo 

type OpCallDepositInfo = DepositTransactionParts;
Available on crate feature optimism only.
Side-channel container for OP-specific deposit info produced by Backend::build_call_env and consumed by the OP transact path.

When the optimism feature is enabled, this is an alias for op_revm::DepositTransactionParts. When disabled, it is a zero-sized stand-in so the eth/tempo dispatch chain still type-checks.

Aliased Type

struct OpCallDepositInfo {
    pub source_hash: FixedBytes<32>,
    pub mint: Option<u128>,
    pub is_system_transaction: bool,
}

Fields

source_hash: FixedBytes<32>

Source hash of the deposit transaction.

mint: Option<u128>

Minted value of the deposit transaction.

is_system_transaction: bool

Whether the transaction is a system transaction.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 80 bytes