fn ensure_mined_trace_block(
block: BlockNumberOrTag,
) -> Result<(), BlockchainError>Expand description
Rejects the pending tag for block trace methods, which only trace mined blocks.
Resolving it to the latest block would present mined transactions as the pending block.